/************************************************/
/* This module checks to see that we are not    */
/* doing IP forwarding on the local machine.    */
/* It basically just checks the ip_forward and  */
/* ip_dynaddr files for 0 and also the network  */
/* file in /etc/sysconfig should contain the    */
/* line: FORWARD_IPV4=FALSE....			*/
/*						*/
/* See lsatmain.c for more details...		*/
/************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int checknetforward(filename, distribution, verbose)
const char *const filename;
int distribution;
int verbose;
{

    int fileval=0;		/* return val  	*/
    FILE *infile;  		 /* tempfile file pointer   	*/
    FILE *outfile; 		 /* output file pointer     	*/

    if (verbose == 1)
    {
        printf("In checknetforward module...\n");
    }


    /* open the output file for append. */
    outfile = fopen(filename, "a");
    if (outfile == NULL)
    {
        perror("Error opening outfile.\n");
        perror("Check perms perhaps?\n");
	printf("Error was in checknetforward module.\n");
        return(-1);
    }

    if (verbose == 1)
    {
        printf("Checking for existance of forwards...\n");
    }

    /* print some header info... */
    fprintf(outfile, "****************************************\n");
    fprintf(outfile, "IP forward files to check:\n\n");


    /* on redhat check /proc/sys/net/ipv4/ip_forward & ip_dynaddr */
    /* also check /etc/sysconfig/network			  */

    if ((distribution == 1) || (distribution == 2))
    {
        if ((system("grep 0 /proc/sys/net/ipv4/ip_forward 1>/dev/null 2>/dev/null")) != 0)
        {
		/* no 0 in ip_forward */
                fprintf(outfile, "ip_forward enabled on this systemn");
		fprintf(outfile, "ensure /proc/sys/net/ipv4/ip_forward\n");
		fprintf(outfile, "contains a 0 only as its entry.\n");
	}
        if ((system("grep FORWARD_IPV4=FALSE /etc/sysconfig/network 1>/dev/null 2>/dev/null")) !=0)
        {
                /* no FALSE for IPforwarding */
                fprintf(outfile, "Make sure that /etc/sysconfig/network\n");
		fprintf(outfile, "contains the line FORWARD_IPV4=FALSE\n");
	}
    }

    /* Assume Solaris/SunOS */
    if ((distribution == 3))
    {
        if ((system("grep \'ip_forwarding 0\' /etc/rc2.d/S69inet 1>/dev/null 2>/dev/null")) != 0)
        {
                fprintf(outfile, "Make sure that ip_forwarding is disabled\n");
		fprintf(outfile, "in /etc/rc2.d/S69inet\n");
	}
	if ((system("grep \'ip_forwarding_src_routed 0\' /etc/rc2.d/S69inet 1>/dev/null 2>/dev/null")) != 0)
	{
		fprintf(outfile, "Make sure that ip_forwarding_src_routed is disabled\n");
		fprintf(outfile, "in /etc/rc2.d/S69inet\n");
	}
	if ((system("grep \'ip_forwarding_directed_broadcast 0\' /etc/rc2.d/S69inet 1>/dev/null 2>/dev/null")) != 0)
	{
		fprintf(outfile, "Make sure that ip_forwarding_directed_broadcast is disabled\n");
		fprintf(outfile, "in /etc/rc2.d/S69inet\n");
	}
	if ((system("cat /etc/norouter 1>/dev/null 2>/dev/null")) != 0)
	{
		fprintf(outfile, "Please touch /etc/norouter\n");
	}
	if ((system("cat /etc/defaultrouter 1>/dev/null 2>/dev/null")) != 0)
	{
		fprintf(outfile, "Please touch (at least) /etc/defaultrouter\n");
	}
    }

    /* print some footer information */
    fprintf(outfile, "\n");
    fprintf(outfile, "****************************************\n");


    /* now we close the outfile... */
    fclose(outfile);

    if (verbose == 1)
    {
        printf("Finished module checknetforward.\n");
    }
    return(0);
}
